/****************************************************************************
** Meta object code from reading C++ file 'board.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kshisen-26.07.90/src/board.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'board.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KShisen5BoardE_t {};
} // unnamed namespace

template <> constexpr inline auto KShisen::Board::qt_create_metaobjectdata<qt_meta_tag_ZN7KShisen5BoardE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KShisen::Board",
        "markMatched",
        "",
        "newGameStarted",
        "changed",
        "tileCountChanged",
        "endOfGame",
        "resized",
        "invalidMove",
        "tilesDoNotMatch",
        "selectATile",
        "selectAMove",
        "selectAMatchingTile",
        "cheatStatusChanged",
        "newGame",
        "setPauseEnabled",
        "enabled",
        "setSoundsEnabled",
        "loadSettings",
        "loadTileset",
        "pathToTileset",
        "loadBackground",
        "pathToBackground",
        "undrawConnection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'markMatched'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newGameStarted'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tileCountChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endOfGame'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resized'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invalidMove'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tilesDoNotMatch'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectATile'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectAMove'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectAMatchingTile'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cheatStatusChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newGame'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPauseEnabled'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'setSoundsEnabled'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'loadSettings'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadTileset'
        QtMocHelpers::SlotData<bool(QString const &)>(19, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'loadBackground'
        QtMocHelpers::SlotData<bool(QString const &)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'undrawConnection'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Board, qt_meta_tag_ZN7KShisen5BoardE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KShisen::Board::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KShisen5BoardE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KShisen5BoardE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KShisen5BoardE_t>.metaTypes,
    nullptr
} };

void KShisen::Board::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Board *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->markMatched(); break;
        case 1: _t->newGameStarted(); break;
        case 2: _t->changed(); break;
        case 3: _t->tileCountChanged(); break;
        case 4: _t->endOfGame(); break;
        case 5: _t->resized(); break;
        case 6: _t->invalidMove(); break;
        case 7: _t->tilesDoNotMatch(); break;
        case 8: _t->selectATile(); break;
        case 9: _t->selectAMove(); break;
        case 10: _t->selectAMatchingTile(); break;
        case 11: _t->cheatStatusChanged(); break;
        case 12: _t->newGame(); break;
        case 13: _t->setPauseEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setSoundsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->loadSettings(); break;
        case 16: { bool _r = _t->loadTileset((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->loadBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->undrawConnection(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::markMatched, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::newGameStarted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::changed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::tileCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::endOfGame, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::resized, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::invalidMove, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::tilesDoNotMatch, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::selectATile, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::selectAMove, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::selectAMatchingTile, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)()>(_a, &Board::cheatStatusChanged, 11))
            return;
    }
}

const QMetaObject *KShisen::Board::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KShisen::Board::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KShisen5BoardE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KShisen::Board::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void KShisen::Board::markMatched()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KShisen::Board::newGameStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KShisen::Board::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KShisen::Board::tileCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KShisen::Board::endOfGame()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KShisen::Board::resized()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KShisen::Board::invalidMove()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KShisen::Board::tilesDoNotMatch()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KShisen::Board::selectATile()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KShisen::Board::selectAMove()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KShisen::Board::selectAMatchingTile()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KShisen::Board::cheatStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
